# opclib
A wrapper library for the [Open Pixel Control](https://github.com/zestyping/openpixelcontrol) Python client. Uses [opc.py](https://github.com/scanlime/fadecandy/blob/master/examples/python/opc.py) from the Fadecandy repository.
